@@ -8,7 +8,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "kmime_codecs.h"
+#include "kmime_codecs_p.h"
 #include "kmime_debug.h"
 
 #include <QStringDecoder>
@@ -18,8 +18,8 @@ namespace KMime {
 
 static const char reservedCharacters[] = "\"()<>@,.;:\\[]=";
 
-QByteArray encodeRFC2047String(const QString &src, const QByteArray &charset,
-                               bool addressHeader, bool allow8BitHeaders)
+QByteArray encodeRFC2047String(QStringView src, const QByteArray &charset,
+                               bool addressHeader)
 {
     QByteArray result;
     int start = 0;
@@ -54,10 +54,6 @@ QByteArray encodeRFC2047String(const QString &src, const QByteArray &charset,
         useQEncoding = true;
     }
 
-    if (allow8BitHeaders) {
-        return encoded8Bit;
-    }
-
     int encoded8BitLength = encoded8Bit.length();
     for (int i = 0; i < encoded8BitLength; i++) {
         if (encoded8Bit[i] == ' ') {   // encoding starts at word boundaries
@@ -134,7 +130,7 @@ QByteArray encodeRFC2047String(const QString &src, const QByteArray &charset,
     return result;
 }
 
-QByteArray encodeRFC2047Sentence(const QString &src, const QByteArray &charset)
+QByteArray encodeRFC2047Sentence(QStringView src, const QByteArray &charset)
 {
     QByteArray result;
     const QChar *ch = src.constData();
@@ -152,7 +148,7 @@ QByteArray encodeRFC2047Sentence(const QString &src, const QByteArray &charset)
         if (isAscii && isReserved) {
             const int wordSize = pos - wordStart;
             if (wordSize > 0) {
-                const QString word = src.mid(wordStart, wordSize);
+                const auto word = src.mid(wordStart, wordSize);
                 result += encodeRFC2047String(word, charset);
             }
 
@@ -166,7 +162,7 @@ QByteArray encodeRFC2047Sentence(const QString &src, const QByteArray &charset)
     // Encode the last word
     const int wordSize = pos - wordStart;
     if (wordSize > 0) {
-        const QString word = src.mid(wordStart, pos - wordStart);
+        const auto word = src.mid(wordStart, pos - wordStart);
         result += encodeRFC2047String(word, charset);
     }
 
@@ -174,7 +170,7 @@ QByteArray encodeRFC2047Sentence(const QString &src, const QByteArray &charset)
 }
 
 //-----------------------------------------------------------------------------
-QByteArray encodeRFC2231String(const QString &str, const QByteArray &charset)
+QByteArray encodeRFC2231String(QStringView str, const QByteArray &charset)
 {
     if (str.isEmpty()) {
       return {};
@@ -234,56 +230,4 @@ QByteArray encodeRFC2231String(const QString &str, const QByteArray &charset)
     return result;
 }
 
-//-----------------------------------------------------------------------------
-QString decodeRFC2231String(const QByteArray &str, QByteArray &usedCS, const QByteArray &defaultCS,
-                            bool forceCS)
-{
-    int p = str.indexOf('\'');
-    if (p < 0) {
-        QStringDecoder codec(defaultCS.constData());
-        if (!codec.isValid()) {
-            codec = QStringDecoder(QStringDecoder::System);
-        }
-        return codec.decode(str);
-    }
-
-    QByteArray charset = str.left(p);
-
-    QByteArray st = str.mid(str.lastIndexOf('\'') + 1);
-
-    char ch;
-    char ch2;
-    p = 0;
-    while (p < st.length()) {
-        if (st.at(p) == 37) {
-            // Only try to decode the percent-encoded character if the percent sign
-            // is really followed by two other characters, see testcase at bug 163024
-            if (p + 2 < st.length()) {
-                ch = st.at(p + 1) - 48;
-                if (ch > 16) {
-                    ch -= 7;
-                }
-                ch2 = st.at(p + 2) - 48;
-                if (ch2 > 16) {
-                    ch2 -= 7;
-                }
-                st[p] = ch * 16 + ch2;
-                st.remove(p + 1, 2);
-            }
-        }
-        p++;
-    }
-    qCDebug(KMIME_LOG) << "Got pre-decoded:" << st;
-    QStringDecoder charsetcodec(charset.constData());
-    if (!charsetcodec.isValid() || forceCS) {
-        charsetcodec = QStringDecoder(defaultCS.constData());
-    }
-    if (!charsetcodec.isValid()) {
-        charsetcodec = QStringDecoder(QStringDecoder::System);
-    }
-
-    usedCS = charsetcodec.name();
-    return charsetcodec.decode(st);
-}
-
 }
