@@ -7,7 +7,7 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#include "kmime_parsers.h"
+#include "kmime_parsers_p.h"
 
 #include <QRegularExpression>
 
@@ -104,7 +104,7 @@ NonMimeParser::NonMimeParser(const QByteArray &src) :
 {
 }
 
-NonMimeParser::~NonMimeParser() {}
+NonMimeParser::~NonMimeParser() = default;
 
 /**
  * try to guess the mimetype from the file-extension
